@@ -29,9 +29,17 @@ has exclude_globs => (
     default => sub { $_[0]->config->exclude_file },
 );
 
-has status => (is => 'rw', default => sub { 0 });
+has include_globs => (
+    is      => 'rw',
+    lazy    => 1,
+    default => sub { $_[0]->config->include_file },
+);
+
+has status        => (is => 'rw', default => sub { 0 });
 has destfile_nice => (is => 'rw');
 
+our $found_comp;
+
 sub do {
     my ($self) = @_;
     $self->parse_copyrights or $self->make_orig_targz;
@@ -89,10 +97,11 @@ sub make_orig_targz {
             }
         }
 
-# Figure out the top-level contents of the tarball.
-# If we'd pass "." to tar we'd get the same contents, but the filenames would
-# start with ./, which is confusing later.
-# This should also be more reliable than, say, changing directories and globbing.
+        # Figure out the top-level contents of the tarball.
+        # If we'd pass "." to tar we'd get the same contents, but the filenames
+        # would start with ./, which is confusing later.
+        # This should also be more reliable than, say, changing directories and
+        # globbing.
         unless (opendir(TMPDIR, $tempdir)) {
             ds_die("Can't open $tempdir $!\n");
             return $self->status(1);
@@ -121,7 +130,10 @@ sub make_orig_targz {
             compress_archive($destfiletar, $destfile,
                 $self->config->compression);
         };
-        return $self->status(1) if ($@);
+        if ($@) {
+            ds_die($@);
+            return $self->status(1);
+        }
 
         # rename means the user did not want this file to exist afterwards
         if ($self->config->mode eq "rename") {
@@ -131,10 +143,12 @@ sub make_orig_targz {
 
         $self->config->mode('repack');
         $upstream_tar = $destfile;
+    } elsif (compression_guess_from_file($upstream_tar) =~ /^zstd?$/) {
+        $self->config->force_repack(1);
     }
 
-# From now on, $upstream_tar is guaranteed to be a compressed tarball. It is always
-# a full (possibly relative) path, and distinct from $destfile.
+    # From now on, $upstream_tar is guaranteed to be a compressed tarball. It
+    # is always a full (possibly relative) path, and distinct from $destfile.
 
     # Find out if we have to repack
     my $do_repack = 0;
@@ -176,8 +190,11 @@ sub make_orig_targz {
               = map { { glob => $_, used => 0, regex => glob_to_regex($_) } }
               @{ $self->exclude_globs };
         };
-        return $self->status(1) if ($@);
-        for my $filename (@files) {
+        if ($@) {
+            ds_die($@);
+            return $self->status(1);
+        }
+        for my $filename (sort @files) {
             my $last_match;
             for my $info (@exclude_info) {
                 if (
@@ -187,7 +204,27 @@ sub make_orig_targz {
 				(?:/.*)?$          # Possible trailing / for a directory
 			      @x
                 ) {
-                    $delete{$filename} = 1 if !$last_match;
+                    if (!$last_match) {
+                        # if the current entry is a directory, check if it
+                        # matches any exclude-ignored glob
+                        my $ignore_this_exclude = 0;
+                        for my $ignore_exclude (@{ $self->include_globs }) {
+                            my $ignore_exclude_regex
+                              = glob_to_regex($ignore_exclude);
+
+                            if ($filename =~ $ignore_exclude_regex) {
+                                $ignore_this_exclude = 1;
+                                last;
+                            }
+                            if (   $filename =~ m,/$,
+                                && $ignore_exclude =~ $info->{regex}) {
+                                $ignore_this_exclude = 1;
+                                last;
+                            }
+                        }
+                        next if $ignore_this_exclude;
+                        $delete{$filename} = 1;
+                    }
                     $last_match = $info;
                 }
             }
@@ -233,7 +270,10 @@ sub make_orig_targz {
         }
         if ($self->config->upstream_comp) {
             eval { decompress_archive($upstream_tar, $destfiletar) };
-            return $self->status(1) if ($@);
+            if ($@) {
+                ds_die($@);
+                return $self->status(1);
+            }
         } else {
             copy $upstream_tar, $destfiletar;
         }
@@ -307,9 +347,6 @@ sub make_orig_targz {
 
     # Final step: symlink, copy or rename for signature file.
 
-    my $is_ascfile = $self->config->signature_file =~ /\.asc$/i;
-    my $is_gpgfile = $self->config->signature_file =~ /\.(gpg|pgp|sig|sign)$/i;
-
     my $destsigfile;
     if ($self->config->signature == 1) {
         $destsigfile = sprintf "%s.asc", $destfile;
@@ -324,22 +361,43 @@ sub make_orig_targz {
     }
 
     if ($self->config->signature == 1 or $self->config->signature == 2) {
-        if ($is_gpgfile) {
-            my $enarmor
-              = `gpg --output - --enarmor $self->{config}->{signature_file} 2>&1`;
+        my $is_openpgp_ascii_armor = 0;
+        my $fh_sig;
+        unless (open($fh_sig, '<', $self->config->signature_file)) {
+            ds_die "Cannot open $self->{config}->{signature_file}\n";
+            return $self->status(1);
+        }
+        while (<$fh_sig>) {
+            if (m/^-----BEGIN PGP /) {
+                $is_openpgp_ascii_armor = 1;
+                last;
+            }
+        }
+        close($fh_sig);
+
+        if (not $is_openpgp_ascii_armor) {
+            my @enarmor
+              = `gpg --no-options --output - --enarmor $self->{config}->{signature_file} 2>&1`;
             unless ($? == 0) {
                 ds_die
-"mk-origtargz: Failed to convert $self->{config}->{signature_file} to *.asc\n";
+"Failed to convert $self->{config}->{signature_file} to *.asc\n";
                 return $self->status(1);
             }
-            $enarmor =~ s/ARMORED FILE/SIGNATURE/;
-            $enarmor =~ /^Comment:/d;
-            unless (open(DESTSIG, ">> $destsigfile")) {
+            unless (open(DESTSIG, '>', $destsigfile)) {
+                ds_die "Failed to open $destsigfile for write $!\n";
+                return $self->status(1);
+            }
+            foreach my $line (@enarmor) {
+                next if $line =~ m/^Version:/;
+                next if $line =~ m/^Comment:/;
+                $line =~ s/ARMORED FILE/SIGNATURE/;
+                print DESTSIG $line;
+            }
+            unless (close(DESTSIG)) {
                 ds_die
-                  "mk-origtargz: Failed to open $destsigfile for append: $!\n";
+"Cannot write signature file $self->{config}->{signature_file}\n";
                 return $self->status(1);
             }
-            print DESTSIG $enarmor;
         } else {
             if (abs_path($self->config->signature_file) ne
                 abs_path($destsigfile)) {
@@ -526,6 +584,12 @@ sub parse_copyrights {
                     grep { $_ }
                       split(/\s+/, $data->{ $self->config->excludestanza }));
             }
+            if ($data->{ $self->config->includestanza }) {
+                push(
+                    @{ $self->include_globs },
+                    grep { $_ }
+                      split(/\s+/, $data->{ $self->config->includestanza }));
+            }
         } else {
             if (open my $file, '<', $copyright_file) {
                 while (my $line = <$file>) {
@@ -554,8 +618,9 @@ sub fix_dest_file {
         $self->config->compression($comp
               || &Devscripts::MkOrigtargz::Config::default_compression);
     }
-    return sprintf "%s.%s", $destfiletar,
-      compression_get_property($self->config->compression, "file_ext");
+    $comp = compression_get_property($self->config->compression, "file_ext");
+    $found_comp ||= $self->config->compression;
+    return sprintf "%s.%s", $destfiletar, $comp;
 }
 
 1;
