@@ -112,7 +112,7 @@ has sigfile  => (is => 'rw');
 # 2 - Line options read/write attributes
 
 foreach (qw(
-    component hrefdecode repacksuffix unzipopt searchmode
+    component ctype hrefdecode repacksuffix unzipopt searchmode
     dirversionmangle downloadurlmangle dversionmangle filenamemangle pagemangle
     oversionmangle oversionmanglepagemangle pgpsigurlmangle uversionmangle
     versionmangle
@@ -167,6 +167,10 @@ has decompress => (
     is      => 'rw',
     default => sub { 0 },
 );
+has gitexport => (
+    is      => 'rw',
+    default => sub { 'default' },
+);
 has gitmode => (
     is      => 'rw',
     default => sub { 'shallow' },
@@ -309,6 +313,11 @@ following keys:
 # or
 #   http://site.name/dir/path/project.git HEAD [version [action]]
 #
+# For svn sites:
+#   http://site.name/dir/path/project/tags v([\d\.]+)\/ [version [action]]
+# or
+#   http://site.name/dir/path/project/trunk HEAD [version [action]]
+#
 # watch_version=3 and 4: See POD for details.
 #
 # Lines can be prefixed with opts=<opts> but can be folded for readability.
@@ -352,7 +361,7 @@ sub parse {
           $self->line, 5;
         if (  !$lastversion
             or $site =~ /\(.*\)/
-            or $dir =~ /\(.*\)/) {
+            or $dir  =~ /\(.*\)/) {
             uscan_warn <<EOF;
 there appears to be a version 2 format line in
 the version 1 watch file $watchfile;
@@ -426,6 +435,7 @@ EOF
             }
             my @opts = split /,/, $opts;
             foreach my $opt (@opts) {
+                next unless ($opt =~ /\S/);
                 uscan_verbose "Parsing $opt";
                 if ($opt =~ /^\s*pasv\s*$/ or $opt =~ /^\s*passive\s*$/) {
                     $self->downloader->pasv(1);
@@ -460,7 +470,9 @@ EOF
                 #
                 # $ regexp-assemble <<EOF
                 # component
+                # ctype
                 # date
+                # gitexport
                 # gitmode
                 # hrefdecode
                 # mode
@@ -471,7 +483,7 @@ EOF
                 # unzipopt
                 # EOF
                 elsif ($opt
-                    =~ /^\s*((?:(?:(?:search|git)?m|hrefdec)od|dat)e|(?:componen|unzipop)t|p(?:gpmode|retty)|repacksuffix)\s*=\s*(.+?)\s*$/
+                    =~ /^\s*((?:(?:(?:(?:search)?m|hrefdec)od|dat)e|c(?:omponent|type)|git(?:export|mode)|p(?:gpmode|retty)|repacksuffix|unzipopt))\s*=\s*(.+?)\s*$/
                 ) {
                     $self->$1($2);
                 } elsif ($opt =~ /^\s*versionmangle\s*=\s*(.+?)\s*$/) {
@@ -558,7 +570,8 @@ EOF
 
         # Set $lastversion to the numeric last version
         # Update $self->versionmode (its default "newer")
-        if (!length($lastversion) or $lastversion =~ /^(group|debian)$/) {
+        if (!length($lastversion)
+            or $lastversion =~ /^(group|checksum|debian)$/) {
             if (!defined $self->pkg_version) {
                 uscan_warn "Unable to determine the current version\n"
                   . "  in $watchfile, skipping:\n  $self->{line}";
@@ -579,7 +592,8 @@ EOF
 
         # Check $filepattern has ( ...)
         if ($filepattern !~ /\([^?].*\)/) {
-            if ($self->mode eq 'git' and $filepattern eq 'HEAD') {
+            if (($self->mode eq 'git' or $self->mode eq 'svn')
+                and $filepattern eq 'HEAD') {
                 $self->versionless(1);
             } elsif ($self->mode eq 'git'
                 and $filepattern =~ m&^heads/&) {
@@ -603,6 +617,12 @@ EOF
               . "  $self->{line}";
             return $self->status(1);
         }
+        if ($self->mode ne 'git' and $self->gitexport ne 'default') {
+            uscan_warn "gitexport option is valid only in git mode,\n"
+              . "  ignoring gitexport in $watchfile:\n"
+              . "  $self->{line}";
+            return $self->status(1);
+        }
 
         # Limit use of opts="repacksuffix" to the single upstream package
         if ($self->repacksuffix and @{ $self->shared->{components} }) {
@@ -641,6 +661,15 @@ EOF
             $self->pgpmode('default');
         }
 
+        # For mode=svn, make pgpmode=none the default
+        if ($self->mode eq 'svn') {
+            if ($self->pgpmode eq 'default') {
+                $self->pgpmode('none');
+            } elsif ($self->pgpmode ne 'none') {
+                uscan_die "Only pgpmode=none can be used with mode=svn.\n";
+            }
+        }
+
         # If PGP used, check required programs and generate files
         if (@{ $self->pgpsigurlmangle }) {
             my $pgpsigurlmanglestring = join(";", @{ $self->pgpsigurlmangle });
@@ -718,6 +747,24 @@ EOF
 
     }
 
+    if ($self->ctype) {
+        my $version;
+        my $mod = "Devscripts::Uscan::Ctype::$self->{ctype}";
+        eval "require $mod";
+        if ($@) {
+            uscan_warn "unknown ctype $self->{ctype}";
+            uscan_debug $@;
+            return $self->status(1);
+        }
+        my $dir            = $self->component || '.';
+        my $ctypeTransform = $mod->new({ dir => $dir });
+        if ($version = $ctypeTransform->version) {
+            $lastversion = $version;
+            uscan_verbose "Found version $version for component $dir";
+            $self->versionmode('newer');
+        }
+    }
+
     # End parsing the watch line for all version=1/2/3/4
     # all options('...') variables have been set
 
@@ -754,7 +801,9 @@ EOF
     }
 
     # Set $download_version etc. if already known
-    if ($self->config->download_version) {
+    if ($self->versionmode eq 'ignore' and $self->config->download_version) {
+        uscan_verbose 'Ignore --download_version for component with "ignore"';
+    } elsif ($self->config->download_version) {
         $self->shared->{download_version} = $self->config->download_version;
         $self->shared->{download}         = 2
           if $self->shared->{download} == 1;    # Change default 1 -> 2
@@ -798,7 +847,8 @@ EOF
 "Unable to set versionmode=prev for the line without opts=pgpmode=prev\n"
                   . "  in $watchfile, skipping:\n  $self->{line}";
             } else {
-                uscan_warn "Nothing was downloaded before, skipping pgp check";
+                uscan_verbose
+                  "Nothing was downloaded before, skipping pgp check";
                 uscan_verbose "  line " . $self->line;
             }
             return $self->status(1);
@@ -835,7 +885,7 @@ EOF
 
             # Find the path with the greatest version number matching the regex
             $base
-              = recursive_regex_dir($self->downloader, $base,
+              = recursive_regex_dir($self, $base,
                 $self->dirversionmangle, $watchfile, \$self->line,
                 $self->shared->{download_version});
             if ($base eq '') {
@@ -847,6 +897,7 @@ EOF
             # It's fine even for ftp sites
             $basedir = $base;
             $basedir =~ s%^\w+://[^/]+/%/%;
+            $basedir =~ s%/[^/]*(?:[#?].*)?$%/%;
             $pattern
               = "(?:(?:$site)?" . quotemeta($basedir) . ")?$filepattern";
         } else {
@@ -904,6 +955,7 @@ Search new file link and new version on the remote site using either:
 =item L<Devscripts::Uscan::http>::http_search()
 =item L<Devscripts::Uscan::ftp>::ftp_search()
 =item L<Devscripts::Uscan::git>::git_search()
+=item L<Devscripts::Uscan::svn>::svn_search()
 
 =back
 
@@ -929,8 +981,8 @@ sub search {
     uscan_verbose "Looking at \$base = $self->{parse_result}->{base} with\n"
       . "    \$filepattern = $self->{parse_result}->{filepattern} found\n"
       . "    \$newfile     = $newfile\n"
-      . "    \$newversion  = $newversion which is newer than\n"
-      . "    \$lastversion = $self->{parse_result}->{lastversion}";
+      . "    \$newversion  = $newversion\n"
+      . "    \$lastversion = $self->{parse_result}->{mangled_lastversion}";
     $self->search_result({
         newversion => $newversion,
         newfile    => $newfile,
@@ -971,6 +1023,7 @@ Transform newfile/newversion into upstream url using either:
 =item L<Devscripts::Uscan::http>::http_upstream_url()
 =item L<Devscripts::Uscan::ftp>::ftp_upstream_url()
 =item L<Devscripts::Uscan::git>::git_upstream_url()
+=item L<Devscripts::Uscan::svn>::svn_upstream_url()
 
 =back
 
@@ -981,8 +1034,9 @@ Result is stored in B<$self-E<gt>upstream_url> accessor.
 sub get_upstream_url {
     my ($self) = @_;
     uscan_debug "line: get_upstream_url()";
-    if ($self->parse_result->{site} =~ m%^https?://%
-        and not $self->mode eq 'git') {
+    if (    $self->parse_result->{site} =~ m%^https?://%
+        and not $self->mode eq 'git'
+        and not $self->mode eq 'svn') {
         $self->mode('http');
     } elsif (not $self->mode) {
         $self->mode('ftp');
@@ -1005,6 +1059,7 @@ Calculates the filename (filenamemangled) for downloaded file using either:
 =item L<Devscripts::Uscan::http>::http_newfile_base()
 =item L<Devscripts::Uscan::ftp>::ftp_newfile_base()
 =item L<Devscripts::Uscan::git>::git_newfile_base()
+=item L<Devscripts::Uscan::svn>::svn_newfile_base()
 
 =back
 
@@ -1033,16 +1088,29 @@ Compare available and local versions.
 sub cmp_versions {
     my ($self) = @_;
     uscan_debug "line: cmp_versions()";
+    my $name                = $self->component || $self->pkg;
     my $mangled_lastversion = $self->parse_result->{mangled_lastversion};
     unless (defined $self->shared->{common_newversion}) {
         $self->shared->{common_newversion}
           = $self->search_result->{newversion};
     }
 
-    $dehs_tags->{'debian-uversion'} = $self->parse_result->{lastversion};
-    $dehs_tags->{'debian-mangled-uversion'} = $mangled_lastversion;
-    $dehs_tags->{'upstream-version'} = $self->search_result->{newversion};
-    $dehs_tags->{'upstream-url'} //= $self->upstream_url;
+    $dehs_tags->{'debian-uversion'} //= $self->parse_result->{lastversion};
+    $dehs_tags->{'debian-mangled-uversion'} //= $mangled_lastversion;
+    $dehs_tags->{'upstream-version'} //= $self->search_result->{newversion};
+    $dehs_tags->{'upstream-url'}     //= $self->upstream_url;
+    $dehs_tags->{'component-name'}   //= [];
+    $dehs_tags->{'component-upstream-version'} //= [];
+    if ($self->component) {
+        push @{ $dehs_tags->{'component-name'} }, $self->component;
+        push @{ $dehs_tags->{'component-debian-uversion'} },
+          $self->parse_result->{lastversion};
+        push @{ $dehs_tags->{'component-debian-mangled-uversion'} },
+          $mangled_lastversion;
+        push @{ $dehs_tags->{'component-upstream-version'} },
+          $self->search_result->{newversion};
+        push @{ $dehs_tags->{'component-upstream-url'} }, $self->upstream_url;
+    }
 
     my $mangled_ver
       = Dpkg::Version->new("1:${mangled_lastversion}-0", check => 0);
@@ -1059,76 +1127,76 @@ sub cmp_versions {
     }
 
     # Version dependent $download adjustment
-    if (defined $self->shared->{download_version}) {
+    if (defined $self->shared->{download_version}
+        and not $self->versionmode eq 'ignore') {
 
         # Pretend to find a newer upstream version to exit without error
-        uscan_msg "Newest version of $self->{pkg} on remote site is "
+        uscan_msg "Newest version of $name on remote site is "
           . "$self->{search_result}->{newversion}, "
           . "specified download version is $self->{shared}->{download_version}";
-        $main::found++;
+        $found++ unless ($self->versionmode =~ /(?:same|ignore)/);
     } elsif ($self->versionmode eq 'newer') {
         if ($compver eq 'newer') {
-            uscan_msg "Newest version of $self->{pkg} on remote site is "
+            uscan_msg "Newest version of $name on remote site is "
               . "$self->{search_result}->{newversion}, "
-              . "local version is $self->{parse_result}->{lastversion}\n"
+              . "local version is $self->{parse_result}->{mangled_lastversion}\n"
               . (
                 $mangled_lastversion eq $self->parse_result->{lastversion}
                 ? ""
-                : " (mangled local version is $mangled_lastversion)\n"
+                : "       (mangled local version is $mangled_lastversion)\n"
               );
 
             # There's a newer upstream version available, which may already
             # be on our system or may not be
-            uscan_msg "   => Newer package available from\n"
-              . "      $self->{upstream_url}";
-            $dehs_tags->{'status'} = "newer package available";
+            uscan_msg " => Newer package available from:\n"
+              . "        => $self->{upstream_url}";
+            $dehs_tags->{'status'} //= "newer package available";
             $main::found++;
         } elsif ($compver eq 'same') {
-            uscan_verbose "Newest version of $self->{pkg} on remote site is "
+            uscan_verbose "Newest version of $name on remote site is "
               . $self->search_result->{newversion}
-              . ", local version is $self->{parse_result}->{lastversion}\n"
+              . ", local version is $self->{parse_result}->{mangled_lastversion}\n"
               . (
                 $mangled_lastversion eq $self->parse_result->{lastversion}
                 ? ""
-                : " (mangled local version is $mangled_lastversion)\n"
+                : "            (mangled local version is $mangled_lastversion)\n"
               );
-            uscan_verbose "   => Package is up to date for from\n"
-              . "      $self->{upstream_url}";
-            $dehs_tags->{'status'} = "up to date";
+            uscan_verbose " => Package is up to date from:\n"
+              . "             => $self->{upstream_url}";
+            $dehs_tags->{'status'} //= "up to date";
             if ($self->shared->{download} > 1) {
 
                 # 2=force-download or 3=overwrite-download
-                uscan_verbose "   => Forcing download as requested";
+                uscan_verbose " => Forcing download as requested";
                 $main::found++;
             } else {
                 # 0=no-download or 1=download
                 $self->shared->{download} = 0;
             }
         } else {    # $compver eq 'old'
-            uscan_verbose "Newest version of $self->{pkg} on remote site is "
+            uscan_verbose "Newest version of $name on remote site is "
               . $self->search_result->{newversion}
-              . ", local version is $self->{parse_result}->{lastversion}\n"
+              . ", local version is $self->{parse_result}->{mangled_lastversion}\n"
               . (
                 $mangled_lastversion eq $self->parse_result->{lastversion}
                 ? ""
-                : " (mangled local version is $mangled_lastversion)\n"
+                : "            (mangled local version is $mangled_lastversion)\n"
               );
-            uscan_verbose "   => Only older package available from\n"
-              . "      $self->{upstream_url}";
-            $dehs_tags->{'status'} = "only older package available";
+            uscan_verbose " => Only older package available from:\n"
+              . "             => $self->{upstream_url}";
+            $dehs_tags->{'status'} //= "only older package available";
             if ($self->shared->{download} > 1) {
-                uscan_verbose "   => Forcing download as requested";
+                uscan_verbose " => Forcing download as requested";
                 $main::found++;
             } else {
                 $self->shared->{download} = 0;
             }
         }
     } elsif ($self->versionmode eq 'ignore') {
-        uscan_msg "Newest version of $self->{pkg} on remote site is "
+        uscan_msg "Newest version of $name on remote site is "
           . $self->search_result->{newversion}
           . ", ignore local version";
-        $dehs_tags->{'status'} = "package available";
-        $main::found++;
+        $dehs_tags->{'status'} //= "package available";
     } else {    # same/previous -- secondary-tarball or signature-file
         uscan_die "strange ... <version> stanza = same/previous "
           . "should have defined \$download_version";
@@ -1144,6 +1212,8 @@ Download file and, if available and needed, signature files.
 
 =cut
 
+my %already_downloaded;
+
 sub download_file_and_sig {
     my ($self) = @_;
     uscan_debug "line: download_file_and_sig()";
@@ -1155,11 +1225,20 @@ sub download_file_and_sig {
         return 0;
     }
 
+    # configure downloader
+    $self->downloader->git_export_all($self->gitexport eq 'all');
+
     # 6.1 download tarball
     my $download_available = 0;
+    my $upstream_base      = basename($self->upstream_url);
     $self->signature_available(0);
     my $sigfile;
     my $sigfile_base = $self->newfile_base;
+    uscan_die
+"Already downloaded a file named $self->{newfile_base}: use filenamemangle to avoid this"
+      if ($already_downloaded{ $self->{newfile_base} });
+    $already_downloaded{ $self->{newfile_base} } = 1;
+
     if ($self->pgpmode ne 'previous') {
 
         # try download package
@@ -1181,7 +1260,7 @@ sub download_file_and_sig {
                   "Successfully downloaded package: $self->{newfile_base}\n";
             } else {
                 dehs_verbose
-"Failed to download upstream package: $self->{newfile_base}\n";
+                  "Failed to download upstream package: $upstream_base\n";
             }
         } elsif (-e "$self->{config}->{destdir}/$self->{newfile_base}") {
             $download_available = 1;
@@ -1189,8 +1268,7 @@ sub download_file_and_sig {
               "Not downloading, using existing file: $self->{newfile_base}\n";
             $skip_git_vrfy = 1;
         } elsif ($self->shared->{download} > 0) {
-            uscan_verbose
-              "Downloading upstream package: $self->{newfile_base}";
+            uscan_verbose "Downloading upstream package: $upstream_base";
             $download_available = $self->downloader->download(
                 $self->upstream_url,
                 "$self->{config}->{destdir}/$self->{newfile_base}",
@@ -1202,15 +1280,18 @@ sub download_file_and_sig {
             );
             if ($download_available) {
                 dehs_verbose
-                  "Successfully downloaded package: $self->{newfile_base}\n";
+                  "Successfully downloaded upstream package: $upstream_base\n";
+                if (@{ $self->filenamemangle }) {
+                    dehs_verbose
+                      "Renamed upstream package to: $self->{newfile_base}\n";
+                }
             } else {
                 dehs_verbose
-"Failed to download upstream package: $self->{newfile_base}\n";
+                  "Failed to download upstream package: $upstream_base\n";
             }
         } else {    # $download = 0,
             $download_available = 0;
-            dehs_verbose
-              "Not downloading upstream package: $self->{newfile_base}\n";
+            dehs_verbose "Not downloading upstream package: $upstream_base\n";
         }
     }
     if ($self->pgpmode eq 'self') {
@@ -1243,7 +1324,7 @@ sub download_file_and_sig {
         # Decompress archive if requested and applicable
         if ($download_available == 1 and $self->{'decompress'}) {
             my $suffix_gz = $sigfile_base;
-            $suffix_gz =~ s/.*?(\.gz|\.xz|\.bz2|\.lzma)?$/$1/;
+            $suffix_gz =~ s/.*?(\.gz|\.xz|\.bz2|\.lzma|\.zstd?)?$/$1/;
             if ($suffix_gz eq '.gz') {
                 if (-x '/bin/gunzip') {
                     uscan_exec('/bin/gunzip', "--keep",
@@ -1280,6 +1361,15 @@ sub download_file_and_sig {
                     uscan_warn "Please install xz-utils or lzma.";
                     return $self->status(1);
                 }
+            } elsif ($suffix_gz =~ /^zstd?$/) {
+                if (-x '/usr/bin/unzstd') {
+                    uscan_exec('/usr/bin/unzstd', "--keep",
+                        "$self->{config}->{destdir}/$sigfile_base");
+                    $sigfile_base =~ s/(.*?)\.zst/$1/;
+                } else {
+                    uscan_warn("Please install zstd.\n");
+                    return $self->status(1);
+                }
             } else {
                 uscan_die "Unknown type file to decompress: $sigfile_base";
             }
@@ -1340,7 +1430,7 @@ sub download_file_and_sig {
         }
         $sigfile = "$sigfile_base.$suffix_sig";
         if ($self->shared->{signature} == 1) {
-            uscan_verbose "Downloading OpenPGP signature from\n"
+            uscan_verbose "Downloading OpenPGP signature from:\n"
               . "   $pgpsig_url (pgpsigurlmangled)\n   as $sigfile";
             $self->signature_available(
                 $self->downloader->download(
@@ -1350,7 +1440,7 @@ sub download_file_and_sig {
                     $self->mode
                 ));
         } else {    # -1, 0
-            uscan_verbose "Not downloading OpenPGP signature from\n"
+            uscan_verbose "Not downloading OpenPGP signature from:\n"
               . "   $pgpsig_url (pgpsigurlmangled)\n   as $sigfile";
             $self->signature_available(
                 (-e "$self->{config}->{destdir}/$sigfile") ? 1 : 0);
@@ -1359,7 +1449,7 @@ sub download_file_and_sig {
         $pgpsig_url = $self->upstream_url;
         $sigfile    = $self->newfile_base;
         if ($self->shared->{signature} == 1) {
-            uscan_verbose "Downloading OpenPGP signature from\n"
+            uscan_verbose "Downloading OpenPGP signature from:\n"
               . "   $pgpsig_url (pgpmode=previous)\n   as $sigfile";
             $self->signature_available(
                 $self->downloader->download(
@@ -1369,7 +1459,7 @@ sub download_file_and_sig {
                     $self->mode
                 ));
         } else {    # -1, 0
-            uscan_verbose "Not downloading OpenPGP signature from\n"
+            uscan_verbose "Not downloading OpenPGP signature from:\n"
               . "   $pgpsig_url (pgpmode=previous)\n   as $sigfile";
             $self->signature_available(
                 (-e "$self->{config}->{destdir}/$sigfile") ? 1 : 0);
@@ -1445,8 +1535,12 @@ sub download_file_and_sig {
             return $self->status(1);
         } else {
             my ($gitrepo, $gitref) = split /[[:space:]]+/, $self->upstream_url;
-            $self->keyring->verify_git($self->pkg . "-temporary.$$.git",
-                $gitref, $self->downloader->git_upstream);
+            $self->keyring->verify_git(
+                "$self->{downloader}->{destdir}/"
+                  . $self->pkg
+                  . "-temporary.$$.git",
+                $gitref, $self->downloader->git_upstream
+            );
         }
     } else {
         uscan_warn "strange ... unknown pgpmode = $self->{pgpmode}";
@@ -1515,8 +1609,13 @@ sub mkorigtargz {
     my $mk_origtargz_out;
     my $path   = "$self->{config}->{destdir}/$self->{newfile_base}";
     my $target = $self->newfile_base;
-    unless ($self->symlink eq "no") {
+    unless ($self->symlink eq "no" or $self->symlink eq "0") {
         require Devscripts::MkOrigtargz;
+        if ($Devscripts::MkOrigtargz::found_comp) {
+            uscan_verbose
+              "Forcing compression to $Devscripts::MkOrigtargz::found_comp";
+            $self->repack(1);
+        }
         @ARGV = ();
         push @ARGV, "--package", $self->pkg;
         push @ARGV, "--version", $self->shared->{common_mangled_newversion};
@@ -1533,8 +1632,9 @@ sub mkorigtargz {
         push @ARGV, "--force-repack" if $self->force_repack;
         push @ARGV, "--component", $self->component
           if $self->component;
-        push @ARGV, "--compression",    $self->compression;
-        push @ARGV, "--directory",      $self->config->destdir;
+        push @ARGV, "--compression",
+          $Devscripts::MkOrigtargz::found_comp || $self->compression;
+        push @ARGV, "--directory", $self->config->destdir;
         push @ARGV, "--copyright-file", "debian/copyright"
           if ($self->config->exclusion && -e "debian/copyright");
         push @ARGV, "--copyright-file", $self->config->copyright_file
@@ -1620,8 +1720,13 @@ sub mkorigtargz {
     }
 
     dehs_verbose "$mk_origtargz_out\n" if $mk_origtargz_out;
-    $dehs_tags->{target} = $target;
-    $dehs_tags->{'target-path'} = $path;
+    if ($self->component) {
+        push @{ $dehs_tags->{"component-target"} },      $target;
+        push @{ $dehs_tags->{"component-target-path"} }, $path;
+    } else {
+        $dehs_tags->{target}        = $target;
+        $dehs_tags->{'target-path'} = $path;
+    }
 
 #######################################################################
     # code 3.10: call uupdate
@@ -1689,6 +1794,7 @@ Clean temporary files using either:
 =item L<Devscripts::Uscan::http>::http_clean()
 =item L<Devscripts::Uscan::ftp>::ftp_clean()
 =item L<Devscripts::Uscan::git>::git_clean()
+=item L<Devscripts::Uscan::svn>::svn_clean()
 
 =back
 
